@@ -476,6 +476,10 @@ class Activity(ModelSQL, ModelView):
         RecordActivity = pool.get('marketing.automation.record.activity')
         record = activity.record
 
+        # As it is a reference, the record may have been deleted
+        if not record:
+            return
+
         # XXX: use domain
         if self.condition and not record.eval(self.condition):
             return
@@ -629,9 +633,10 @@ class Record(ModelSQL, ModelView):
     def get_models(self):
         pool = Pool()
         Model = pool.get('ir.model')
+        Scenario = pool.get('marketing.automation.scenario')
 
         if not self.scenario:
-            return [('', '')]
+            return Scenario.get_models()
 
         model, = Model.search([
                 ('model', '=', self.scenario.model),
@@ -670,7 +675,10 @@ class Record(ModelSQL, ModelView):
         cls.write(records, {'blocked': True})
 
     def get_rec_name(self, name):
-        return self.record.rec_name
+        if self.record:
+            return self.record.rec_name
+        else:
+            return '(%s)' % self.id
 
     @classmethod
     def create(cls, vlist):
